import graphene
from graphene_django import DjangoObjectType

from blog.models import Autor, Articulo, Categoria

class AutorType(DjangoObjectType):
    class Meta:
        model = Autor
        fields = ("id", "nombre", "apellidos", "usuario")

class ArticuloType(DjangoObjectType):
    class Meta:
        model = Articulo
        fields = ("id", "titulo", "contenido","autor", "categoria")

class CategoriaType(DjangoObjectType):
    class Meta:
        model = Categoria
        fields = ("id", "nombre")

class Query(graphene.ObjectType):
    todos_autores = graphene.List(AutorType)
    articulos_por_autor = graphene.List(ArticuloType, id=graphene.Int(required=True))

    def resolve_todos_autores(root, info):
        return Autor.objects.all()

    def resolve_articulos_por_autor(root, info, id):
        return Articulo.objects.select_related('autor').select_related("categoria").filter(autor=id)
        
schema = graphene.Schema(query=Query)